==> huaweicloudsdklive-3.1.73-py2.py3-none-any.whl: huaweicloudsdklive/v1/model/show_domain_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowDomainResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'float',
        'domain_info': 'list[DecoupledLiveDomainInfo]'
    }

    attribute_map = {
        'total': 'total',
        'domain_info': 'domain_info'
    }

    def __init__(self, total=None, domain_info=None):
        """ShowDomainResponse

        The model defined in huaweicloud sdk

        :param total: 查询结果的总数量
        :type total: float
        :param domain_info: 直播域名列表
        :type domain_info: list[:class:`huaweicloudsdklive.v1.DecoupledLiveDomainInfo`]
        """
        
        super(ShowDomainResponse, self).__init__()

        self._total = None
        self._domain_info = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if domain_info is not None:
            self.domain_info = domain_info

    @property
    def total(self):
        """Gets the total of this ShowDomainResponse.

        查询结果的总数量

        :return: The total of this ShowDomainResponse.
        :rtype: float
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ShowDomainResponse.

        查询结果的总数量

        :param total: The total of this ShowDomainResponse.
        :type total: float
        """
        self._total = total

    @property
    def domain_info(self):
        """Gets the domain_info of this ShowDomainResponse.

        直播域名列表

        :return: The domain_info of this ShowDomainResponse.
        :rtype: list[:class:`huaweicloudsdklive.v1.DecoupledLiveDomainInfo`]
        """
        return self._domain_info

    @domain_info.setter
    def domain_info(self, domain_info):
        """Sets the domain_info of this ShowDomainResponse.

        直播域名列表

        :param domain_info: The domain_info of this ShowDomainResponse.
        :type domain_info: list[:class:`huaweicloudsdklive.v1.DecoupledLiveDomainInfo`]
        """
        self._domain_info = domain_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowDomainResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdklive-3.1.155-py2.py3-none-any.whl: huaweicloudsdklive/v1/model/show_domain_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowDomainResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'float',
        'domain_info': 'list[DecoupledLiveDomainInfo]'
    }

    attribute_map = {
        'total': 'total',
        'domain_info': 'domain_info'
    }

    def __init__(self, total=None, domain_info=None):
        r"""ShowDomainResponse

        The model defined in huaweicloud sdk

        :param total: 查询结果的总数量
        :type total: float
        :param domain_info: 直播域名列表
        :type domain_info: list[:class:`huaweicloudsdklive.v1.DecoupledLiveDomainInfo`]
        """
        
        super(ShowDomainResponse, self).__init__()

        self._total = None
        self._domain_info = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if domain_info is not None:
            self.domain_info = domain_info

    @property
    def total(self):
        r"""Gets the total of this ShowDomainResponse.

        查询结果的总数量

        :return: The total of this ShowDomainResponse.
        :rtype: float
        """
        return self._total

    @total.setter
    def total(self, total):
        r"""Sets the total of this ShowDomainResponse.

        查询结果的总数量

        :param total: The total of this ShowDomainResponse.
        :type total: float
        """
        self._total = total

    @property
    def domain_info(self):
        r"""Gets the domain_info of this ShowDomainResponse.

        直播域名列表

        :return: The domain_info of this ShowDomainResponse.
        :rtype: list[:class:`huaweicloudsdklive.v1.DecoupledLiveDomainInfo`]
        """
        return self._domain_info

    @domain_info.setter
    def domain_info(self, domain_info):
        r"""Sets the domain_info of this ShowDomainResponse.

        直播域名列表

        :param domain_info: The domain_info of this ShowDomainResponse.
        :type domain_info: list[:class:`huaweicloudsdklive.v1.DecoupledLiveDomainInfo`]
        """
        self._domain_info = domain_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowDomainResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
